@@ -3,7 +3,6 @@ from .main import *
 from .temporal import *
 from .time import *
 
-
 __all__ = [
     # boxes
     'TBox', 'STBox',
@@ -19,4 +18,10 @@ __all__ = [
     'Temporal', 'TInstant', 'TemporalInstants', 'TInstantSet', 'TSequence', 'TSequenceSet',
     # time
     'Period', 'TimestampSet', 'PeriodSet'
-    ]
+]
+
+from warnings import warn
+
+warn('The python-mobilitydb package is now deprecated and will no longer be mantained.'
+     'Instead, the use of the new PyMEOS package is recommended. Check it out at https://pypi.org/project/pymeos/',
+     DeprecationWarning, stacklevel=2)
